==> korweblog-1.5.8.tar.gz: korweblog-1.5.8/include/users.inc.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001,2002 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

function KWL_GetUserInfo($q,$d) {
	$userinfo = SqlQueryFetchArray("SELECT * FROM T_Users WHERE $q = '$d'");
	return $userinfo;
}

function KWL_CheckUserPasswd($name,$passwd) {
	$name = trim($name);
	$passwd = trim($passwd);
   if (KWL_CheckUserName($name)) {
      $orig_pass = SqlResult("SELECT pass FROM T_Users WHERE name = '$name'");
      if (empty($orig_pass)) KWL_ShowError(_NO_USER);
      if (crypt($passwd, $orig_pass)==$orig_pass) return true;
   }
   return false;
}

function KWL_MakePasswd() {
	$makepass="";
	$syllables="er,in,tia,wol,fe,pre,vet,jo,nes,al,len,son,cha,ir,ler,bo,ok,tio,nar,sim,ple,bla,ten,toe,cho,co,lat,spe,ak,er,po,co,lor,pen,cil,li,ght,wh,at,the,he,ck,is,mam,bo,no,fi,ve,any,way,pol,iti,cs,ra,dio,sou,rce,sea,rch,pa,per,com,bo,sp,eak,st,fi,rst,gr,oup,boy,ea,gle,tr,ail,bi,ble,brb,pri,dee,kay,en,be,se";
	$syllable_array=explode(",", $syllables);
	srand((double)microtime()*1000000);
	for ($count=1;$count<=4;$count++) {
		if (rand()%10 == 1) {
			$makepass .= sprintf("%0.0f",(rand()%50)+1);
		} else {
			$makepass .= sprintf("%s",$syllable_array[rand()%62]);
		}
	}
	return($makepass);
}

function KWL_CookieDecode($str) {
   return explode(":", base64_decode($str));
}

function KWL_DoCookie($name,$info,$life='') {
	if (empty($life)) $ct = 0;
	else $ct = time() + $life;
	setcookie("$name",base64_encode($info),$ct);
}

function KWL_CheckUserName($name) {
	$len = strlen($name);
	if ($len < 4 || $len > 20) return false;
	elseif (eregi("[^\xA1-\xFEa-z0-9\. ]",$name)) return false;
   elseif (strtolower($name) == "anonymous") return false;
	else return true;
}

function KWL_BookmarkList($uid,$fix='') {
	if ($fix) {
		$sql = "SELECT id,uid,rid,pid FROM T_UBookmark WHERE uid='$uid' ORDER BY id DESC";
		return SqlQuery($sql);
	} else {
		return SqlCount("T_UBookmark","uid",$uid);
	}
}

function KWL_BookmarkSave($uid,$rid) {
   $count = SqlCount("T_UBookmark","uid",$uid);
   if (KWL_GetConf('Bmark_limit') < $count) {
      $lid = SqlResult("SELECT id FROM T_UBookmark WHERE uid='$uid' ORDER BY id ASC LIMIT 0,1");
      SqlQuery("DELETE FROM T_UBookmark WHERE id='$lid'");
   }
   
   if (KWL_ValidRid($rid)) {
      $pid = SqlResult("SELECT ParentRid FROM T_Comments WHERE Rid='$rid' LIMIT 0,1");
      if (empty($pid)) $pid = "story";
      $sql  = "INSERT INTO T_UBookmark VALUES ('','$uid','$rid','$pid')";
      return SqlQuery($sql);
   }
}

function KWL_UserNavig() {
	$CONF = KWL_GetConf();

	$url['home'] = "<A HREF=\"$CONF[G_URL]/user.php\">";
	$url['config'] = "<A HREF=\"$CONF[G_URL]/config.php\">";
	$url['msg'] = "<A HREF=\"$CONF[G_URL]/priv_msg.php\">";
	$url['bmark'] = "<A HREF=\"$CONF[G_URL]/user.php?what=bmark\">";
	$url['ulist'] = "<A HREF=\"$CONF[G_URL]/user.php?what=userlist\">";
	$url['logout'] = "<A HREF=\"$CONF[G_URL]/user.php?what=logout\">";
   $url['post'] = "<A HREF=\"$CONF[G_URL]/user.php?what=mypost\">";
	
	$A['Heading'] = _UHOME;
	$A['Content'] = "<TABLE BORDER=\"0\" CELLSPACING=\"2\" CELLPADDING=\"3\" WIDTH=\"100%\">";
	if ($CONF['uh_image']) {
		$A['Content'] .= "<TR>"
		. "<TD ALIGN=CENTER>$url[home]<IMG SRC=\"$CONF[G_URL]/images.d/user/home.gif\" BORDER=\"0\" VSPACE=\"0\" HSPACE=\"0\" ALT=\"Home\"></A></TD>"
		. "<TD ALIGN=CENTER>$url[config]<IMG SRC=\"$CONF[G_URL]/images.d/user/config.gif\" BORDER=\"0\" VSPACE=\"0\" HSPACE=\"0\" ALT=\"". _CONFIG ."\"></A></TD>"
	   . ($CONF['Private_msg'] ? "<TD ALIGN=CENTER>$url[msg]<IMG SRC=\"$CONF[G_URL]/images.d/user/msg.gif\" BORDER=\"0\" VSPACE=\"0\" HSPACE=\"0\" ALT=\"". _PRIV_MSG ."\"></A></TD>" : "")
	   . "<TD ALIGN=CENTER>$url[post]<IMG SRC=\"$CONF[G_URL]/images.d/user/posted.gif\" BORDER=\"0\" VSPACE=\"0\" HSPACE=\"0\" ALT=\"". _MY_POST ."\"></A></TD>"
		. ($CONF['Bookmark'] ? "<TD ALIGN=CENTER>$url[bmark]<IMG SRC=\"$CONF[G_URL]/images.d/user/bookmark.gif\" BORDER=\"0\" VSPACE=\"0\" HSPACE=\"0\" ALT=\"". _BOOKMARK ."\"></A></TD>" : "")
		. ($CONF['User_list'] ? "<TD ALIGN=CENTER>$url[ulist]<IMG SRC=\"$CONF[G_URL]/images.d/user/ulist.gif\" BORDER=\"0\" VSPACE=\"0\" HSPACE=\"0\" ALT=\"". _USER_LIST ."\"></A></TD>" : "")
		. "<TD ALIGN=CENTER>$url[logout]<IMG SRC=\"$CONF[G_URL]/images.d/user/logout.gif\" BORDER=\"0\" VSPACE=\"0\" HSPACE=\"0\" ALT=\"Logout\"></A></TD></TR>";
	}

	$A['Content'] .= "<TR>".
      "<TD ALIGN=CENTER>$url[home]Home</A></TD>".
      "<TD ALIGN=CENTER>$url[config]". _CONFIG ."</A></TD>".
      ($CONF['Private_msg'] ? "<TD ALIGN=CENTER>$url[msg]". _PRIV_MSG ."</A></TD>" : "").
      "<TD ALIGN=CENTER>$url[post]". _MY_POST ."</A></TD>".
      ($CONF['Bookmark'] ? "<TD ALIGN=CENTER>$url[bmark]". _BOOKMARK ."</A></TD>" : "").
      ($CONF['User_list'] ? "<TD ALIGN=CENTER>$url[ulist]". _USER_LIST ."</A></TD>" : "").
      "<TD ALIGN=CENTER>$url[logout]Logout</A></TD>".
      "</TR></TABLE>";
	KWL_DrawMain($A);
}

function KWL_CheckNewUser($name,$email) {
	if (empty($name) || !KWL_CheckUserName($name)) KWL_ShowError(_USER_REGISTER1);
	$email = KWL_EmailCheck($email);
	if (empty($email)) KWL_ShowError(_USER_REGISTER2); 
	
	if (SqlCount("T_Users","name",$name)) KWL_ShowError(_USER_REGISTER3);
	/* admin can register same email address */
	if (!KWL_GetConf('admin_login')) {
		if (SqlCount("T_Users","email",$email)) KWL_ShowError(_USER_REGISTER4);
	}	
}

function KWL_CheckPasswd($colume,$rid,$passwd) {
   $orig_pass = SqlResult("SELECT passwd FROM $colume WHERE Rid = '$rid'");
   if (md5($passwd) == KWL_GetConf("Passwd")) return 1;
   if (!empty($passwd) && !empty($orig_pass)) {
      if (crypt($passwd, $orig_pass)==$orig_pass) return 1;
   }
}

function KWL_SaveUserCookie($Author,$AuthorEmail,$AuthorURL) {
	$name	= KWL_GetConf("SiteKey") . "_userinfo";
	KWL_DoCookie(md5($name),"$Author|$AuthorEmail|$AuthorURL",5800000);
}

function KWL_GetCookieUser() {
   global $C_USER;
   if (isset($_COOKIE[$C_USER])) {
      return explode("|",base64_decode($_COOKIE[$C_USER]));
   }
}
?>

==> korweblog-1.6.0.tar.gz: korweblog-1.6.0/include/users.inc.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

function KWL_GetUserInfo($q,$d) {
	$userinfo = SqlQueryFetchArray("SELECT * FROM T_Users WHERE $q = '$d'");
	return $userinfo;
}

function KWL_CheckUserPasswd($name,$passwd) {
	$name = trim($name);
	$passwd = trim($passwd);
   if (KWL_CheckUserName($name)) {
      $orig_pass = SqlResult("SELECT pass FROM T_Users WHERE name = '$name'");
      if (empty($orig_pass)) KWL_ShowError(_NO_USER);
      if (crypt($passwd, $orig_pass)==$orig_pass) return true;
   }
   return false;
}

function KWL_MakePasswd() {
	$makepass="";
	$syllables="er,in,tia,wol,fe,pre,vet,jo,nes,al,len,son,cha,ir,ler,bo,ok,tio,nar,sim,ple,bla,ten,toe,cho,co,lat,spe,ak,er,po,co,lor,pen,cil,li,ght,wh,at,the,he,ck,is,mam,bo,no,fi,ve,any,way,pol,iti,cs,ra,dio,sou,rce,sea,rch,pa,per,com,bo,sp,eak,st,fi,rst,gr,oup,boy,ea,gle,tr,ail,bi,ble,brb,pri,dee,kay,en,be,se";
	$syllable_array=explode(",", $syllables);
	srand((double)microtime()*1000000);
	for ($count=1;$count<=4;$count++) {
		if (rand()%10 == 1) {
			$makepass .= sprintf("%0.0f",(rand()%50)+1);
		} else {
			$makepass .= sprintf("%s",$syllable_array[rand()%62]);
		}
	}
	return($makepass);
}

function KWL_CookieDecode($str) {
   return explode(":", base64_decode($str));
}

function KWL_DoCookie($name,$info,$life='') {
	if (empty($life)) $ct = 0;
	else $ct = time() + $life;
	setcookie("$name",base64_encode($info),$ct);
}

function KWL_CheckUserName($name) {
	$len = strlen($name);
	if ($len < 4 || $len > 20) return false;
	elseif (eregi("[^\xA1-\xFEa-z0-9\. ]",$name)) return false;
   elseif (strtolower($name) == "anonymous") return false;
	else return true;
}

function KWL_BookmarkList($uid,$fix='') {
	if ($fix) {
		$sql = "SELECT id,uid,rid,pid FROM T_UBookmark WHERE uid='$uid' ORDER BY id DESC";
		return SqlQuery($sql);
	} else {
		return SqlCount("T_UBookmark","uid",$uid);
	}
}

function KWL_BookmarkSave($uid,$rid) {
   $count = SqlCount("T_UBookmark","uid",$uid);
   if (KWL_GetConf('Bmark_limit') < $count) {
      $lid = SqlResult("SELECT id FROM T_UBookmark WHERE uid='$uid' ORDER BY id ASC LIMIT 0,1");
      SqlQuery("DELETE FROM T_UBookmark WHERE id='$lid'");
   }
   
   if (KWL_ValidRid($rid)) {
      $pid = SqlResult("SELECT ParentRid FROM T_Comments WHERE Rid='$rid' LIMIT 0,1");
      if (empty($pid)) $pid = "story";
      $sql  = "INSERT INTO T_UBookmark VALUES ('','$uid','$rid','$pid')";
      return SqlQuery($sql);
   }
}

function KWL_UserNavig() {
	$CONF = KWL_GetConf();

	$url['home'] = "<a href=\"$CONF[G_URL]/user.php\">";
	$url['config'] = "<a href=\"$CONF[G_URL]/config.php\">";
	$url['msg'] = "<a href=\"$CONF[G_URL]/priv_msg.php\">";
	$url['bmark'] = "<a href=\"$CONF[G_URL]/user.php?what=bmark\">";
	$url['ulist'] = "<a href=\"$CONF[G_URL]/user.php?what=userlist\">";
	$url['logout'] = "<a href=\"$CONF[G_URL]/user.php?what=logout\">";
   $url['post'] = "<a href=\"$CONF[G_URL]/user.php?what=mypost\">";
	
	$A['Heading'] = _UHOME;
	$A['Content'] = "<table border=\"0\" cellspacing=\"2\" cellpadding=\"3\" width=\"100%\">";
	if ($CONF['uh_image']) {
		$A['Content'] .= "<tr>"
		. "<td align=\"center\">$url[home]<img src=\"$CONF[G_URL]/images.d/user/home.gif\" border=\"0\" vspace=\"0\" hspace=\"0\" alt=\"Home\" /></a></td>"
		. "<td align=\"center\">$url[config]<img src=\"$CONF[G_URL]/images.d/user/config.gif\" border=\"0\" vspace=\"0\" hspace=\"0\" alt=\"". _CONFIG ."\" /></a></td>"
	   . ($CONF['Private_msg'] ? "<td align=\"center\">$url[msg]<img src=\"$CONF[G_URL]/images.d/user/msg.gif\" border=\"0\" vspace=\"0\" hspace=\"0\" alt=\"". _PRIV_MSG ."\" /></a></td>" : "")
	   . "<td align=\"center\">$url[post]<img src=\"$CONF[G_URL]/images.d/user/posted.gif\" border=\"0\" vspace=\"0\" hspace=\"0\" alt=\"". _MY_POST ."\" /></a></td>"
		. ($CONF['Bookmark'] ? "<td align=\"center\">$url[bmark]<img src=\"$CONF[G_URL]/images.d/user/bookmark.gif\" border=\"0\" vspace=\"0\" hspace=\"0\" alt=\"". _BOOKMARK ."\" /></a></td>" : "")
		. ($CONF['User_list'] ? "<td align=\"center\">$url[ulist]<img src=\"$CONF[G_URL]/images.d/user/ulist.gif\" border=\"0\" vspace=\"0\" hspace=\"0\" alt=\"". _USER_LIST ."\" /></a></td>" : "")
		. "<td align=\"center\">$url[logout]<img src=\"$CONF[G_URL]/images.d/user/logout.gif\" border=\"0\" vspace=\"0\" hspace=\"0\" alt=\"Logout\" /></a></td></tr>";
	}

	$A['Content'] .= "<tr>".
      "<td align=\"center\">$url[home]Home</a></td>".
      "<td align=\"center\">$url[config]". _CONFIG ."</a></td>".
      ($CONF['Private_msg'] ? "<td align=\"center\">$url[msg]". _PRIV_MSG ."</a></td>" : "").
      "<td align=\"center\">$url[post]". _MY_POST ."</a></td>".
      ($CONF['Bookmark'] ? "<td align=\"center\">$url[bmark]". _BOOKMARK ."</a></td>" : "").
      ($CONF['User_list'] ? "<td align=\"center\">$url[ulist]". _USER_LIST ."</a></td>" : "").
      "<td align=\"center\">$url[logout]Logout</a></td>".
      "</tr></table>";
	KWL_DrawMain($A);
}

function KWL_CheckNewUser($name,$email) {
	if (empty($name) || !KWL_CheckUserName($name)) KWL_ShowError(_USER_REGISTER1);
	$email = KWL_EmailCheck($email);
	if (empty($email)) KWL_ShowError(_USER_REGISTER2); 
	
	if (SqlCount("T_Users","name",$name)) KWL_ShowError(_USER_REGISTER3);
	/* admin can register same email address */
	if (!KWL_GetConf('admin_login')) {
		if (SqlCount("T_Users","email",$email)) KWL_ShowError(_USER_REGISTER4);
	}	
}

function KWL_CheckPasswd($colume,$rid,$passwd) {
   $orig_pass = SqlResult("SELECT passwd FROM $colume WHERE Rid = '$rid'");
   if (md5($passwd) == KWL_GetConf("Passwd")) return 1;
   if (!empty($passwd) && !empty($orig_pass)) {
      if (crypt($passwd, $orig_pass)==$orig_pass) return 1;
   }
}

function KWL_SaveUserCookie($Author,$AuthorEmail,$AuthorURL) {
	$name	= KWL_GetConf("SiteKey") . "_userinfo";
	KWL_DoCookie(md5($name),"$Author|$AuthorEmail|$AuthorURL",5800000);
}

function KWL_GetCookieUser() {
   global $C_USER;
   if (isset($_COOKIE[$C_USER])) {
      return explode("|",base64_decode($_COOKIE[$C_USER]));
   }
}
?>
